---
name: Bug report
about: Report a bug to help us improve
title: 'Bug report'
labels: "Type: Bug"
---

<!--
IMPORTANT NOTES

Thank you for taking the time to report a bug. If you aren't certain whether an issue
is a bug, please first open a Discussion. Before submitting, please reread your
description to ensure that other readers can reasonably understand the issue
you're facing and the impact on your workflow or results.

This form is written in GitHub's Markdown format. For a reference on this type
of syntax, see GitHub's documentation:
https://docs.github.com/en/get-started/writing-on-github/getting-started-with-writing-and-formatting-on-github/basic-writing-and-formatting-syntax

This template contains guidance for your submission within the < ! - -, - - > blocks.
These are comments in HTML syntax and will not appear in the submission.
Be sure to use the "Preview" feature on GitHub to ensure your submission is formatted as intended.

When including code snippets, please paste the text itself and wrap the code block with
ticks (see the other character on the tilde ~ key in a US keyboard) to format it as code.
For example, Python code should be wrapped in ticks like this:
```python
def a_func():
    return 1

a = 1
b = a_func()
print(a + b)
```
This is preferred over screen shots since it is searchable and others can copy/paste
the text to run it.
-->

# Add meaningful title here
<!--
A clear and concise description of the bug including what happened
and what you expected to happen.
-->

## How to reproduce
<!--
Describe how another person with no context can recreate this issue.
It is typically very helpful to reduce the problem as much as possible
and share a minimum working example. See the note above on including
code as text rather than screenshots.
-->

## Relevant output
<!--
Include any output, plots, or other means of communication here to add context to the problem.
 -->

## GreenHEART version
<!--
Share your GreenHEART version and how you installed it. You can print the GreenHEART version from
a Python REPL or script with these commands:
```python
import greenheart
print(greenheart.__version__)
```
 -->

## System Information
<!-- Add your information here. -->
 - OS: <e.g. Ubuntu 20.04 or macOS 10.12>
 - Python version: <Result of `python --version`>
 - Relevant library versions, from the results of `pip freeze`, for example:
   - FLORIS
   - HOPP
   - matplotlib
   - NREL-PySAM
   - numpy
   - numexpr
   - orbit-nrel
   - pandas
   - scipy
   - shapely
